You are viewing a plain text version of this content. The canonical link for it is here.
Posted to kalumet-commits@incubator.apache.org by jb...@apache.org on 2012/08/30 17:31:30 UTC

svn commit: r1379028 [7/7] - in /incubator/kalumet/trunk: ./ documentation/src/site/apt/ documentation/src/site/apt/adminguide/ documentation/src/site/apt/userguide/ documentation/src/site/apt/userguide/environment/ kalumet-modules/agent/src/main/java/...

Modified: incubator/kalumet/trunk/kalumet-modules/console/src/main/java/org/apache/kalumet/console/app/PublishReleaseWindow.java
URL: http://svn.apache.org/viewvc/incubator/kalumet/trunk/kalumet-modules/console/src/main/java/org/apache/kalumet/console/app/PublishReleaseWindow.java?rev=1379028&r1=1379027&r2=1379028&view=diff
==============================================================================
--- incubator/kalumet/trunk/kalumet-modules/console/src/main/java/org/apache/kalumet/console/app/PublishReleaseWindow.java (original)
+++ incubator/kalumet/trunk/kalumet-modules/console/src/main/java/org/apache/kalumet/console/app/PublishReleaseWindow.java Thu Aug 30 17:31:27 2012
@@ -32,13 +32,8 @@ import nextapp.echo2.app.event.ActionEve
 import nextapp.echo2.app.event.ActionListener;
 import org.apache.commons.vfs.FileObject;
 import org.apache.kalumet.FileManipulator;
-import org.apache.kalumet.model.Archive;
-import org.apache.kalumet.model.ConfigurationFile;
-import org.apache.kalumet.model.Database;
-import org.apache.kalumet.model.J2EEApplication;
-import org.apache.kalumet.model.J2EEApplicationServer;
-import org.apache.kalumet.model.Software;
-import org.apache.kalumet.model.SqlScript;
+import org.apache.kalumet.model.*;
+import org.apache.kalumet.model.JEEApplication;
 import org.apache.kalumet.utils.VariableUtils;
 
 import java.util.Iterator;
@@ -296,8 +291,8 @@ public class PublishReleaseWindow
           ApplicationCheckBox checkBox = (ApplicationCheckBox) applicationCheckBoxIterator.next();
           if ( checkBox.isSelected() )
           {
-            J2EEApplication application = parent.getEnvironment().getJ2EEApplicationServers().getJ2EEApplicationServer(
-              checkBox.getServerName() ).getJ2EEApplication( checkBox.getApplicationName() );
+            JEEApplication application = parent.getEnvironment().getJEEApplicationServers().getJEEApplicationServer(
+              checkBox.getServerName() ).getJEEApplication( checkBox.getApplicationName() );
             String applicationUri =
               VariableUtils.replace( application.getUri(), parent.getEnvironment().getVariables() );
             FileObject file = fileManipulator.resolveFile( applicationUri );
@@ -311,8 +306,8 @@ public class PublishReleaseWindow
           ArchiveCheckBox checkBox = (ArchiveCheckBox) archiveCheckBoxIterator.next();
           if ( checkBox.isSelected() )
           {
-            J2EEApplication application = parent.getEnvironment().getJ2EEApplicationServers().getJ2EEApplicationServer(
-              checkBox.getServerName() ).getJ2EEApplication( checkBox.getApplicationName() );
+            JEEApplication application = parent.getEnvironment().getJEEApplicationServers().getJEEApplicationServer(
+              checkBox.getServerName() ).getJEEApplication( checkBox.getApplicationName() );
             Archive archive = application.getArchive( checkBox.getArchiveName() );
             String archiveUri;
             if ( FileManipulator.protocolExists( archive.getUri() ) )
@@ -337,8 +332,8 @@ public class PublishReleaseWindow
           ConfigurationFileCheckBox checkBox = (ConfigurationFileCheckBox) configurationFileCheckBoxIterator.next();
           if ( checkBox.isSelected() )
           {
-            J2EEApplication application = parent.getEnvironment().getJ2EEApplicationServers().getJ2EEApplicationServer(
-              checkBox.getServerName() ).getJ2EEApplication( checkBox.getApplicationName() );
+            JEEApplication application = parent.getEnvironment().getJEEApplicationServers().getJEEApplicationServer(
+              checkBox.getServerName() ).getJEEApplication( checkBox.getApplicationName() );
             ConfigurationFile configurationFile =
               application.getConfigurationFile( checkBox.getConfigurationFileName() );
             String configurationFileUri;
@@ -364,8 +359,8 @@ public class PublishReleaseWindow
           SqlScriptCheckBox checkBox = (SqlScriptCheckBox) sqlScriptCheckBoxIterator.next();
           if ( checkBox.isSelected() )
           {
-            J2EEApplication application = parent.getEnvironment().getJ2EEApplicationServers().getJ2EEApplicationServer(
-              checkBox.getServerName() ).getJ2EEApplication( checkBox.getApplicationName() );
+            JEEApplication application = parent.getEnvironment().getJEEApplicationServers().getJEEApplicationServer(
+              checkBox.getServerName() ).getJEEApplication( checkBox.getApplicationName() );
             Database database = application.getDatabase( checkBox.getDatabaseName() );
             SqlScript sqlScript = database.getSqlScript( checkBox.getSqlScriptName() );
             String sqlScriptUri;
@@ -479,14 +474,14 @@ public class PublishReleaseWindow
     column.add( applicationLocationField );
     // add applications checkbox
     for ( Iterator applicationServerIterator =
-            parent.getEnvironment().getJ2EEApplicationServers().getJ2EEApplicationServers().iterator();
+            parent.getEnvironment().getJEEApplicationServers().getJEEApplicationServers().iterator();
           applicationServerIterator.hasNext(); )
     {
-      J2EEApplicationServer applicationServer = (J2EEApplicationServer) applicationServerIterator.next();
-      for ( Iterator applicationIterator = applicationServer.getJ2EEApplications().iterator();
+      JEEApplicationServer applicationServer = (JEEApplicationServer) applicationServerIterator.next();
+      for ( Iterator applicationIterator = applicationServer.getJEEApplications().iterator();
             applicationIterator.hasNext(); )
       {
-        J2EEApplication application = (J2EEApplication) applicationIterator.next();
+        JEEApplication application = (JEEApplication) applicationIterator.next();
         ApplicationCheckBox checkBox = new ApplicationCheckBox( applicationServer.getName(), application.getName() );
         checkBox.setStyleName( "default" );
         applicationCheckBoxes.add( checkBox );
@@ -505,14 +500,14 @@ public class PublishReleaseWindow
     column.add( archiveLocationField );
     // add archives checkbox
     for ( Iterator applicationServerIterator =
-            parent.getEnvironment().getJ2EEApplicationServers().getJ2EEApplicationServers().iterator();
+            parent.getEnvironment().getJEEApplicationServers().getJEEApplicationServers().iterator();
           applicationServerIterator.hasNext(); )
     {
-      J2EEApplicationServer applicationServer = (J2EEApplicationServer) applicationServerIterator.next();
-      for ( Iterator applicationIterator = applicationServer.getJ2EEApplications().iterator();
+      JEEApplicationServer applicationServer = (JEEApplicationServer) applicationServerIterator.next();
+      for ( Iterator applicationIterator = applicationServer.getJEEApplications().iterator();
             applicationIterator.hasNext(); )
       {
-        J2EEApplication application = (J2EEApplication) applicationIterator.next();
+        JEEApplication application = (JEEApplication) applicationIterator.next();
         for ( Iterator archiveIterator = application.getArchives().iterator(); archiveIterator.hasNext(); )
         {
           Archive archive = (Archive) archiveIterator.next();
@@ -536,14 +531,14 @@ public class PublishReleaseWindow
     column.add( configurationFileLocationField );
     // add configuration files checkbox
     for ( Iterator applicationServerIterator =
-            parent.getEnvironment().getJ2EEApplicationServers().getJ2EEApplicationServers().iterator();
+            parent.getEnvironment().getJEEApplicationServers().getJEEApplicationServers().iterator();
           applicationServerIterator.hasNext(); )
     {
-      J2EEApplicationServer applicationServer = (J2EEApplicationServer) applicationServerIterator.next();
-      for ( Iterator applicationIterator = applicationServer.getJ2EEApplications().iterator();
+      JEEApplicationServer applicationServer = (JEEApplicationServer) applicationServerIterator.next();
+      for ( Iterator applicationIterator = applicationServer.getJEEApplications().iterator();
             applicationIterator.hasNext(); )
       {
-        J2EEApplication application = (J2EEApplication) applicationIterator.next();
+        JEEApplication application = (JEEApplication) applicationIterator.next();
         for ( Iterator configurationFileIterator = application.getConfigurationFiles().iterator();
               configurationFileIterator.hasNext(); )
         {
@@ -569,14 +564,14 @@ public class PublishReleaseWindow
     column.add( sqlScriptLocationField );
     // add SQL scripts checkbox
     for ( Iterator applicationServerIterator =
-            parent.getEnvironment().getJ2EEApplicationServers().getJ2EEApplicationServers().iterator();
+            parent.getEnvironment().getJEEApplicationServers().getJEEApplicationServers().iterator();
           applicationServerIterator.hasNext(); )
     {
-      J2EEApplicationServer applicationServer = (J2EEApplicationServer) applicationServerIterator.next();
-      for ( Iterator applicationIterator = applicationServer.getJ2EEApplications().iterator();
+      JEEApplicationServer applicationServer = (JEEApplicationServer) applicationServerIterator.next();
+      for ( Iterator applicationIterator = applicationServer.getJEEApplications().iterator();
             applicationIterator.hasNext(); )
       {
-        J2EEApplication application = (J2EEApplication) applicationIterator.next();
+        JEEApplication application = (JEEApplication) applicationIterator.next();
         for ( Iterator databaseIterator = application.getDatabases().iterator(); databaseIterator.hasNext(); )
         {
           Database database = (Database) databaseIterator.next();

Modified: incubator/kalumet/trunk/kalumet-modules/console/src/main/java/org/apache/kalumet/console/app/SecurityPane.java
URL: http://svn.apache.org/viewvc/incubator/kalumet/trunk/kalumet-modules/console/src/main/java/org/apache/kalumet/console/app/SecurityPane.java?rev=1379028&r1=1379027&r2=1379028&view=diff
==============================================================================
--- incubator/kalumet/trunk/kalumet-modules/console/src/main/java/org/apache/kalumet/console/app/SecurityPane.java (original)
+++ incubator/kalumet/trunk/kalumet-modules/console/src/main/java/org/apache/kalumet/console/app/SecurityPane.java Thu Aug 30 17:31:27 2012
@@ -305,7 +305,7 @@ public class SecurityPane
     }
   };
 
-  // switch J2EE application servers
+  // switch JEE application servers
   private ActionListener switchJeeServers = new ActionListener()
   {
     public void actionPerformed( ActionEvent event )
@@ -469,7 +469,7 @@ public class SecurityPane
     }
   };
 
-  // switch J2EE resources update
+  // switch JEE resources update
   private ActionListener switchJeeResourcesUpdate = new ActionListener()
   {
     public void actionPerformed( ActionEvent event )
@@ -510,7 +510,7 @@ public class SecurityPane
     }
   };
 
-  // switch J2EE applications
+  // switch JEE applications
   private ActionListener switchJeeApplications = new ActionListener()
   {
     public void actionPerformed( ActionEvent event )
@@ -551,7 +551,7 @@ public class SecurityPane
     }
   };
 
-  // switch J2EE applications update
+  // switch JEE applications update
   private ActionListener switchJeeApplicationsUpdate = new ActionListener()
   {
     public void actionPerformed( ActionEvent event )

Modified: incubator/kalumet/trunk/kalumet-modules/console/src/main/java/org/apache/kalumet/console/app/SharedLibrariesPane.java
URL: http://svn.apache.org/viewvc/incubator/kalumet/trunk/kalumet-modules/console/src/main/java/org/apache/kalumet/console/app/SharedLibrariesPane.java?rev=1379028&r1=1379027&r2=1379028&view=diff
==============================================================================
--- incubator/kalumet/trunk/kalumet-modules/console/src/main/java/org/apache/kalumet/console/app/SharedLibrariesPane.java (original)
+++ incubator/kalumet/trunk/kalumet-modules/console/src/main/java/org/apache/kalumet/console/app/SharedLibrariesPane.java Thu Aug 30 17:31:27 2012
@@ -33,7 +33,7 @@ import nextapp.echo2.app.event.ActionLis
 import nextapp.echo2.app.list.DefaultListModel;
 import org.apache.kalumet.console.configuration.ConfigurationManager;
 import org.apache.kalumet.model.Agent;
-import org.apache.kalumet.model.J2EEApplicationServer;
+import org.apache.kalumet.model.JEEApplicationServer;
 import org.apache.kalumet.model.Kalumet;
 import org.apache.kalumet.model.SharedLibrary;
 import org.apache.kalumet.ws.client.SharedLibraryClient;
@@ -186,7 +186,7 @@ public class SharedLibrariesPane
         return;
       }
       // looking for the shared library object
-      SharedLibrary sharedLibrary = parent.getEnvironment().getJ2EEApplicationServers().getJ2EEApplicationServer(
+      SharedLibrary sharedLibrary = parent.getEnvironment().getJEEApplicationServers().getJEEApplicationServer(
         (String) scopeField.getSelectedItem() ).getSharedLibrary( event.getActionCommand() );
       if ( sharedLibrary == null )
       {
@@ -236,7 +236,7 @@ public class SharedLibrariesPane
         return;
       }
       // looking for the shared library object
-      SharedLibrary sharedLibrary = parent.getEnvironment().getJ2EEApplicationServers().getJ2EEApplicationServer(
+      SharedLibrary sharedLibrary = parent.getEnvironment().getJEEApplicationServers().getJEEApplicationServer(
         (String) scopeField.getSelectedItem() ).getSharedLibrary( event.getActionCommand() );
       if ( sharedLibrary == null )
       {
@@ -323,7 +323,7 @@ public class SharedLibrariesPane
         return;
       }
       // looking for the shared library
-      final SharedLibrary sharedLibrary = parent.getEnvironment().getJ2EEApplicationServers().getJ2EEApplicationServer(
+      final SharedLibrary sharedLibrary = parent.getEnvironment().getJEEApplicationServers().getJEEApplicationServer(
         (String) scopeField.getSelectedItem() ).getSharedLibrary( event.getActionCommand() );
       if ( sharedLibrary == null )
       {
@@ -338,7 +338,7 @@ public class SharedLibrariesPane
           public void actionPerformed( ActionEvent event )
           {
             // remove the shared library
-            parent.getEnvironment().getJ2EEApplicationServers().getJ2EEApplicationServer(
+            parent.getEnvironment().getJEEApplicationServers().getJEEApplicationServer(
               (String) scopeField.getSelectedItem() ).getSharedLibraries().remove( sharedLibrary );
             // add a change event
             parent.getChangeEvents().add( "Delete shared library " + sharedLibrary.getName() );
@@ -395,7 +395,7 @@ public class SharedLibrariesPane
       // library name is not already in use
       if ( !name.equals( nameFieldValue ) )
       {
-        if ( parent.getEnvironment().getJ2EEApplicationServers().getJ2EEApplicationServer(
+        if ( parent.getEnvironment().getJEEApplicationServers().getJEEApplicationServer(
           (String) scopeField.getSelectedItem() ).getSharedLibrary( nameFieldValue ) != null )
         {
           KalumetConsoleApplication.getApplication().getLogPane().addWarning(
@@ -404,7 +404,7 @@ public class SharedLibrariesPane
         }
       }
       // looking for the shared library object
-      SharedLibrary sharedLibrary = parent.getEnvironment().getJ2EEApplicationServers().getJ2EEApplicationServer(
+      SharedLibrary sharedLibrary = parent.getEnvironment().getJEEApplicationServers().getJEEApplicationServer(
         (String) scopeField.getSelectedItem() ).getSharedLibrary( name );
       if ( sharedLibrary == null )
       {
@@ -466,7 +466,7 @@ public class SharedLibrariesPane
       // add the shared library
       try
       {
-        parent.getEnvironment().getJ2EEApplicationServers().getJ2EEApplicationServer(
+        parent.getEnvironment().getJEEApplicationServers().getJEEApplicationServer(
           (String) scopeField.getSelectedItem() ).addSharedLibrary( sharedLibrary );
       }
       catch ( Exception e )
@@ -493,7 +493,7 @@ public class SharedLibrariesPane
     public void actionPerformed( ActionEvent event )
     {
       // looking for the shared library object
-      SharedLibrary sharedLibrary = parent.getEnvironment().getJ2EEApplicationServers().getJ2EEApplicationServer(
+      SharedLibrary sharedLibrary = parent.getEnvironment().getJEEApplicationServers().getJEEApplicationServer(
         (String) scopeField.getSelectedItem() ).getSharedLibrary( event.getActionCommand() );
       if ( sharedLibrary == null )
       {
@@ -698,10 +698,10 @@ public class SharedLibrariesPane
     scopeListModel.removeAll();
     // add application servers in the scope select field
     for ( Iterator applicationServerIterator =
-            parent.getEnvironment().getJ2EEApplicationServers().getJ2EEApplicationServers().iterator();
+            parent.getEnvironment().getJEEApplicationServers().getJEEApplicationServers().iterator();
           applicationServerIterator.hasNext(); )
     {
-      J2EEApplicationServer applicationServer = (J2EEApplicationServer) applicationServerIterator.next();
+      JEEApplicationServer applicationServer = (JEEApplicationServer) applicationServerIterator.next();
       scopeListModel.add( applicationServer.getName() );
     }
     if ( scopeListModel.size() > 0 )
@@ -737,10 +737,10 @@ public class SharedLibrariesPane
     int scopeIndex = 0;
     int found = -1;
     for ( Iterator applicationServerIterator =
-            parent.getEnvironment().getJ2EEApplicationServers().getJ2EEApplicationServers().iterator();
+            parent.getEnvironment().getJEEApplicationServers().getJEEApplicationServers().iterator();
           applicationServerIterator.hasNext(); )
     {
-      J2EEApplicationServer applicationServer = (J2EEApplicationServer) applicationServerIterator.next();
+      JEEApplicationServer applicationServer = (JEEApplicationServer) applicationServerIterator.next();
       scopeListModel.add( applicationServer.getName() );
       if ( applicationServer.getName().equals( applicationServerName ) )
       {
@@ -781,7 +781,7 @@ public class SharedLibrariesPane
     classpathHeader.setStyleName( "grid.header" );
     grid.add( classpathHeader );
     // add the shared libraries
-    for ( Iterator sharedLibraryIterator = parent.getEnvironment().getJ2EEApplicationServers().getJ2EEApplicationServer(
+    for ( Iterator sharedLibraryIterator = parent.getEnvironment().getJEEApplicationServers().getJEEApplicationServer(
       applicationServerName ).getSharedLibraries().iterator(); sharedLibraryIterator.hasNext(); )
     {
       SharedLibrary sharedLibrary = (SharedLibrary) sharedLibraryIterator.next();

Modified: incubator/kalumet/trunk/kalumet-modules/console/src/main/java/org/apache/kalumet/console/app/SoftwareWindow.java
URL: http://svn.apache.org/viewvc/incubator/kalumet/trunk/kalumet-modules/console/src/main/java/org/apache/kalumet/console/app/SoftwareWindow.java?rev=1379028&r1=1379027&r2=1379028&view=diff
==============================================================================
--- incubator/kalumet/trunk/kalumet-modules/console/src/main/java/org/apache/kalumet/console/app/SoftwareWindow.java (original)
+++ incubator/kalumet/trunk/kalumet-modules/console/src/main/java/org/apache/kalumet/console/app/SoftwareWindow.java Thu Aug 30 17:31:27 2012
@@ -412,11 +412,11 @@ public class SoftwareWindow
       }
       if ( beforeJeeFieldIndex == 0 )
       {
-        software.setBeforej2ee( true );
+        software.setBeforejee(true);
       }
       else
       {
-        software.setBeforej2ee( false );
+        software.setBeforejee(false);
       }
       software.setUri( uriFieldValue );
       // add the software object if needed
@@ -2238,7 +2238,7 @@ public class SoftwareWindow
     }
     uriField.setText( software.getUri() );
     // update the before JEE field
-    if ( software.isBeforej2ee() )
+    if ( software.isBeforejee() )
     {
       beforeJeeField.setSelectedIndex( 0 );
     }

Modified: incubator/kalumet/trunk/kalumet-modules/console/src/main/java/org/apache/kalumet/console/app/SoftwaresPane.java
URL: http://svn.apache.org/viewvc/incubator/kalumet/trunk/kalumet-modules/console/src/main/java/org/apache/kalumet/console/app/SoftwaresPane.java?rev=1379028&r1=1379027&r2=1379028&view=diff
==============================================================================
--- incubator/kalumet/trunk/kalumet-modules/console/src/main/java/org/apache/kalumet/console/app/SoftwaresPane.java (original)
+++ incubator/kalumet/trunk/kalumet-modules/console/src/main/java/org/apache/kalumet/console/app/SoftwaresPane.java Thu Aug 30 17:31:27 2012
@@ -213,15 +213,15 @@ public class SoftwaresPane
         return;
       }
       // change the external software order
-      if ( software.isBeforej2ee() )
+      if ( software.isBeforejee() )
       {
-        software.setBeforej2ee( false );
-        parent.getChangeEvents().add( "Flag software " + software.getName() + " to be updated after J2EE resources." );
+        software.setBeforejee(false);
+        parent.getChangeEvents().add( "Flag software " + software.getName() + " to be updated after JEE resources." );
       }
       else
       {
-        software.setBeforej2ee( true );
-        parent.getChangeEvents().add( "Flag software " + software.getName() + " to be updated before J2EE resources." );
+        software.setBeforejee(true);
+        parent.getChangeEvents().add( "Flag software " + software.getName() + " to be updated before JEE resources." );
       }
       // change the updated flag
       parent.setUpdated( true );
@@ -655,7 +655,7 @@ public class SoftwaresPane
       grid.add( row );
       // before JEE resources
       Button orderButton;
-      if ( software.isBeforej2ee() )
+      if ( software.isBeforejee() )
       {
         orderButton = new Button( Styles.BOOK_PREVIOUS );
         orderButton.setToolTipText( Messages.getString( "switch.afterjee" ) );

Copied: incubator/kalumet/trunk/kalumet-modules/controller/core/src/main/java/org/apache/kalumet/controller/core/AbstractJEEApplicationServerController.java (from r1377266, incubator/kalumet/trunk/kalumet-modules/controller/core/src/main/java/org/apache/kalumet/controller/core/AbstractJ2EEApplicationServerController.java)
URL: http://svn.apache.org/viewvc/incubator/kalumet/trunk/kalumet-modules/controller/core/src/main/java/org/apache/kalumet/controller/core/AbstractJEEApplicationServerController.java?p2=incubator/kalumet/trunk/kalumet-modules/controller/core/src/main/java/org/apache/kalumet/controller/core/AbstractJEEApplicationServerController.java&p1=incubator/kalumet/trunk/kalumet-modules/controller/core/src/main/java/org/apache/kalumet/controller/core/AbstractJ2EEApplicationServerController.java&r1=1377266&r2=1379028&rev=1379028&view=diff
==============================================================================
--- incubator/kalumet/trunk/kalumet-modules/controller/core/src/main/java/org/apache/kalumet/controller/core/AbstractJ2EEApplicationServerController.java (original)
+++ incubator/kalumet/trunk/kalumet-modules/controller/core/src/main/java/org/apache/kalumet/controller/core/AbstractJEEApplicationServerController.java Thu Aug 30 17:31:27 2012
@@ -21,10 +21,10 @@ package org.apache.kalumet.controller.co
 import java.util.List;
 
 /**
- * Abstract J2EE application server controller.
+ * Abstract JEE application server controller.
  */
-public abstract class AbstractJ2EEApplicationServerController
-  implements J2EEApplicationServerController
+public abstract class AbstractJEEApplicationServerController
+  implements JEEApplicationServerController
 {
 
   private String url;
@@ -40,15 +40,15 @@ public abstract class AbstractJ2EEApplic
   /**
    * Default constructor.
    *
-   * @param url        JMX URL of the J2EE application server.
+   * @param url        JMX URL of the JEE application server.
    * @param username   the administrative user.
    * @param password   the administrative password.
-   * @param serverName the J2EE application server name.
+   * @param serverName the JEE application server name.
    * @param cluster    true means that the server is a cluster, or single.
    * @throws ControllerException in case of connection failure.
    */
-  public AbstractJ2EEApplicationServerController( String url, String username, String password, String serverName,
-                                                  Boolean cluster )
+  public AbstractJEEApplicationServerController(String url, String username, String password, String serverName,
+                                                Boolean cluster)
     throws ControllerException
   {
     this.url = url;
@@ -60,7 +60,7 @@ public abstract class AbstractJ2EEApplic
   }
 
   /**
-   * Abstract method to initialize a specific J2EE application server.
+   * Abstract method to initialize a specific JEE application server.
    *
    * @throws ControllerException in case of initialization error.
    */
@@ -126,17 +126,17 @@ public abstract class AbstractJ2EEApplic
   public abstract boolean isStopped()
     throws ControllerException;
 
-  public abstract boolean isJ2EEApplicationDeployed( String path, String name )
+  public abstract boolean isJEEApplicationDeployed(String path, String name)
     throws ControllerException;
 
-  public abstract void deployJ2EEApplication( String path, String name, String classLoaderOrder,
-                                              String classLoaderPolicy, String virtualHost )
+  public abstract void deployJEEApplication(String path, String name, String classLoaderOrder,
+                                            String classLoaderPolicy, String virtualHost)
     throws ControllerException;
 
-  public abstract void undeployJ2EEApplication( String path, String name )
+  public abstract void undeployJEEApplication(String path, String name)
     throws ControllerException;
 
-  public abstract void redeployJ2EEApplication( String path, String name )
+  public abstract void redeployJEEApplication(String path, String name)
     throws ControllerException;
 
   public abstract boolean isJDBCConnectionPoolDeployed( String name )

Copied: incubator/kalumet/trunk/kalumet-modules/controller/core/src/main/java/org/apache/kalumet/controller/core/JEEApplicationServerController.java (from r1377266, incubator/kalumet/trunk/kalumet-modules/controller/core/src/main/java/org/apache/kalumet/controller/core/J2EEApplicationServerController.java)
URL: http://svn.apache.org/viewvc/incubator/kalumet/trunk/kalumet-modules/controller/core/src/main/java/org/apache/kalumet/controller/core/JEEApplicationServerController.java?p2=incubator/kalumet/trunk/kalumet-modules/controller/core/src/main/java/org/apache/kalumet/controller/core/JEEApplicationServerController.java&p1=incubator/kalumet/trunk/kalumet-modules/controller/core/src/main/java/org/apache/kalumet/controller/core/J2EEApplicationServerController.java&r1=1377266&r2=1379028&rev=1379028&view=diff
==============================================================================
--- incubator/kalumet/trunk/kalumet-modules/controller/core/src/main/java/org/apache/kalumet/controller/core/J2EEApplicationServerController.java (original)
+++ incubator/kalumet/trunk/kalumet-modules/controller/core/src/main/java/org/apache/kalumet/controller/core/JEEApplicationServerController.java Thu Aug 30 17:31:27 2012
@@ -21,13 +21,13 @@ package org.apache.kalumet.controller.co
 import java.util.List;
 
 /**
- * J2EE application server controller interface.
+ * JEE application server controller interface.
  */
-public interface J2EEApplicationServerController
+public interface JEEApplicationServerController
 {
 
   /**
-   * Shutdown a J2EE application server.
+   * Shutdown a JEE application server.
    *
    * @throws ControllerException in case of shutdown failure.
    */
@@ -35,7 +35,7 @@ public interface J2EEApplicationServerCo
     throws ControllerException;
 
   /**
-   * Get the current status of a J2EE application server.
+   * Get the current status of a JEE application server.
    *
    * @return the current human readable status.
    * @throws ControllerException in case of status check failure.
@@ -44,57 +44,57 @@ public interface J2EEApplicationServerCo
     throws ControllerException;
 
   /**
-   * Check if an J2EE application server is stopped or not.
+   * Check if an JEE application server is stopped or not.
    *
-   * @return true if the J2EE application server is stopped, false if it's running.
+   * @return true if the JEE application server is stopped, false if it's running.
    * @throws ControllerException in case of status check failure.
    */
   public boolean isStopped()
     throws ControllerException;
 
   /**
-   * Check if a J2EE application is deployed.
+   * Check if a JEE application is deployed.
    *
    * @param path the application local path.
    * @param name the application name.
-   * @return true if the J2EE application is deployed, false else.
+   * @return true if the JEE application is deployed, false else.
    * @throws ControllerException in case of status check failure.
    */
-  public boolean isJ2EEApplicationDeployed( String path, String name )
+  public boolean isJEEApplicationDeployed(String path, String name)
     throws ControllerException;
 
   /**
-   * Deploy a J2EE application.
+   * Deploy a JEE application.
    *
-   * @param path              the J2EE application local path.
-   * @param name              the J2EE application name.
-   * @param classLoaderOrder  the J2EE application class loader order (PARENT_FIRST/PARENT_LAST).
-   * @param classLoaderPolicy the J2EE application class loader policy (single/multiple).
-   * @param virtualHost       the J2EE application virtual host (if applicable).
+   * @param path              the JEE application local path.
+   * @param name              the JEE application name.
+   * @param classLoaderOrder  the JEE application class loader order (PARENT_FIRST/PARENT_LAST).
+   * @param classLoaderPolicy the JEE application class loader policy (single/multiple).
+   * @param virtualHost       the JEE application virtual host (if applicable).
    * @throws ControllerException in case of deployment failure.
    */
-  public void deployJ2EEApplication( String path, String name, String classLoaderOrder, String classLoaderPolicy,
-                                     String virtualHost )
+  public void deployJEEApplication(String path, String name, String classLoaderOrder, String classLoaderPolicy,
+                                   String virtualHost)
     throws ControllerException;
 
   /**
-   * Undeploy a J2EE application.
+   * Undeploy a JEE application.
    *
-   * @param path the J2EE application local path.
-   * @param name the J2EE application name.
+   * @param path the JEE application local path.
+   * @param name the JEE application name.
    * @throws ControllerException in case of undeployment failure.
    */
-  public void undeployJ2EEApplication( String path, String name )
+  public void undeployJEEApplication(String path, String name)
     throws ControllerException;
 
   /**
-   * Redeploy a J2EE application.
+   * Redeploy a JEE application.
    *
-   * @param path the J2EE application local path.
-   * @param name the J2EE application name.
+   * @param path the JEE application local path.
+   * @param name the JEE application name.
    * @throws ControllerException in case of redeployment failure.
    */
-  public void redeployJ2EEApplication( String path, String name )
+  public void redeployJEEApplication(String path, String name)
     throws ControllerException;
 
   /**

Copied: incubator/kalumet/trunk/kalumet-modules/controller/core/src/main/java/org/apache/kalumet/controller/core/JEEApplicationServerControllerFactory.java (from r1377266, incubator/kalumet/trunk/kalumet-modules/controller/core/src/main/java/org/apache/kalumet/controller/core/J2EEApplicationServerControllerFactory.java)
URL: http://svn.apache.org/viewvc/incubator/kalumet/trunk/kalumet-modules/controller/core/src/main/java/org/apache/kalumet/controller/core/JEEApplicationServerControllerFactory.java?p2=incubator/kalumet/trunk/kalumet-modules/controller/core/src/main/java/org/apache/kalumet/controller/core/JEEApplicationServerControllerFactory.java&p1=incubator/kalumet/trunk/kalumet-modules/controller/core/src/main/java/org/apache/kalumet/controller/core/J2EEApplicationServerControllerFactory.java&r1=1377266&r2=1379028&rev=1379028&view=diff
==============================================================================
--- incubator/kalumet/trunk/kalumet-modules/controller/jboss/src/main/java/org/apache/kalumet/controller/jboss/JBoss4Controller.java (original)
+++ incubator/kalumet/trunk/kalumet-modules/controller/jboss/src/main/java/org/apache/kalumet/controller/jboss/JBoss4Controller.java Thu Aug 30 17:31:27 2012
@@ -22,7 +22,7 @@ import org.apache.commons.io.FileUtils;
 import org.apache.commons.lang.StringUtils;
 import org.apache.kalumet.FileManipulator;
 import org.apache.kalumet.FileManipulatorException;
-import org.apache.kalumet.controller.core.AbstractJ2EEApplicationServerController;
+import org.apache.kalumet.controller.core.AbstractJEEApplicationServerController;
 import org.apache.kalumet.controller.core.ControllerException;
 import org.jboss.jmx.adaptor.rmi.RMIAdaptor;
 import org.slf4j.Logger;
@@ -52,7 +52,7 @@ import java.util.Properties;
  * JBoss4Controller is a controller to connect and manage a JBoss server.
  */
 public class JBoss4Controller
-  extends AbstractJ2EEApplicationServerController
+  extends AbstractJEEApplicationServerController
 {
 
   private final static transient Logger LOGGER = LoggerFactory.getLogger( JBoss4Controller.class );
@@ -209,10 +209,10 @@ public class JBoss4Controller
     }
   }
 
-  public boolean isJ2EEApplicationDeployed( String path, String name )
+  public boolean isJEEApplicationDeployed(String path, String name)
     throws ControllerException
   {
-    LOGGER.info( "Checking if the J2EE application {} is deployed", name );
+    LOGGER.info( "Checking if the JEE application {} is deployed", name );
     String applicationUrl = JBoss4Controller.formatPathToUrl( path );
     boolean deployed = false;
     ObjectName mbean = null;
@@ -224,17 +224,17 @@ public class JBoss4Controller
     }
     catch ( Exception e )
     {
-      LOGGER.error( "Can't check if the J2EE application {} is deployed", name, e );
-      throw new ControllerException( "Can't check if the J2EE application " + name + " is deployed", e );
+      LOGGER.error( "Can't check if the JEE application {} is deployed", name, e );
+      throw new ControllerException( "Can't check if the JEE application " + name + " is deployed", e );
     }
     return deployed;
   }
 
-  public void deployJ2EEApplication( String path, String name, String classloaderorder, String classloaderpolicy,
-                                     String vhost )
+  public void deployJEEApplication(String path, String name, String classloaderorder, String classloaderpolicy,
+                                   String vhost)
     throws ControllerException
   {
-    LOGGER.info( "Deploying the J2EE application {} ({})", name, path );
+    LOGGER.info( "Deploying the JEE application {} ({})", name, path );
     String applicationUrl = JBoss4Controller.formatPathToUrl( path );
     ObjectName mbean = null;
     try
@@ -244,15 +244,15 @@ public class JBoss4Controller
     }
     catch ( Exception e )
     {
-      LOGGER.error( "Can't deploy the J2EE application {}", name, e );
-      throw new ControllerException( "Can't deploy the J2EE application " + name, e );
+      LOGGER.error( "Can't deploy the JEE application {}", name, e );
+      throw new ControllerException( "Can't deploy the JEE application " + name, e );
     }
   }
 
-  public void undeployJ2EEApplication( String path, String name )
+  public void undeployJEEApplication(String path, String name)
     throws ControllerException
   {
-    LOGGER.info( "Undeploying the J2EE application {} ({})", name, path );
+    LOGGER.info( "Undeploying the JEE application {} ({})", name, path );
     String applicationUrl = JBoss4Controller.formatPathToUrl( path );
     ObjectName mbean = null;
     try
@@ -262,15 +262,15 @@ public class JBoss4Controller
     }
     catch ( Exception e )
     {
-      LOGGER.error( "Can't undeploy the J2EE application {}", name, e );
-      throw new ControllerException( "Can't undeploy the J2EE application " + name, e );
+      LOGGER.error( "Can't undeploy the JEE application {}", name, e );
+      throw new ControllerException( "Can't undeploy the JEE application " + name, e );
     }
   }
 
-  public void redeployJ2EEApplication( String path, String name )
+  public void redeployJEEApplication(String path, String name)
     throws ControllerException
   {
-    LOGGER.info( "Redeploying the J2EE application {} ({})", name, path );
+    LOGGER.info( "Redeploying the JEE application {} ({})", name, path );
     String applicationUrl = JBoss4Controller.formatPathToUrl( path );
     ObjectName mbean = null;
     try
@@ -280,8 +280,8 @@ public class JBoss4Controller
     }
     catch ( Exception e )
     {
-      LOGGER.error( "Can't redeploy the J2EE application {}", name, e );
-      throw new ControllerException( "Can't redeploy the J2EE application " + name, e );
+      LOGGER.error( "Can't redeploy the JEE application {}", name, e );
+      throw new ControllerException( "Can't redeploy the JEE application " + name, e );
     }
   }
 

Modified: incubator/kalumet/trunk/kalumet-modules/controller/jboss/src/main/java/org/apache/kalumet/controller/jboss/JBoss6Controller.java
URL: http://svn.apache.org/viewvc/incubator/kalumet/trunk/kalumet-modules/controller/jboss/src/main/java/org/apache/kalumet/controller/jboss/JBoss6Controller.java?rev=1379028&r1=1379027&r2=1379028&view=diff
==============================================================================
--- incubator/kalumet/trunk/kalumet-modules/controller/weblogic/src/main/java/org/apache/kalumet/controller/weblogic/WeblogicController.java (original)
+++ incubator/kalumet/trunk/kalumet-modules/controller/weblogic/src/main/java/org/apache/kalumet/controller/weblogic/WeblogicController.java Thu Aug 30 17:31:27 2012
@@ -18,7 +18,7 @@
  */
 package org.apache.kalumet.controller.weblogic;
 
-import org.apache.kalumet.controller.core.AbstractJ2EEApplicationServerController;
+import org.apache.kalumet.controller.core.AbstractJEEApplicationServerController;
 import org.apache.kalumet.controller.core.ControllerException;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
@@ -50,7 +50,7 @@ import java.util.Properties;
  * WeblogicController is a controller  to manage a Oracle/BEA WebLogic server.
  */
 public class WeblogicController
-  extends AbstractJ2EEApplicationServerController
+  extends AbstractJEEApplicationServerController
 {
 
   private final static transient Logger LOGGER = LoggerFactory.getLogger( WeblogicController.class );
@@ -212,10 +212,10 @@ public class WeblogicController
     }
   }
 
-  public boolean isJ2EEApplicationDeployed( String path, String name )
+  public boolean isJEEApplicationDeployed(String path, String name)
     throws ControllerException
   {
-    LOGGER.info( "Checking if the J2EE application {} is deployed", name );
+    LOGGER.info( "Checking if the JEE application {} is deployed", name );
     try
     {
       home.getAdminMBean( name, "Application", home.getDomainName() );
@@ -227,11 +227,11 @@ public class WeblogicController
     return true;
   }
 
-  public void deployJ2EEApplication( String path, String name, String classloaderorder, String classloaderpolicy,
-                                     String vhost )
+  public void deployJEEApplication(String path, String name, String classloaderorder, String classloaderpolicy,
+                                   String vhost)
     throws ControllerException
   {
-    LOGGER.info( "Deploying J2EE application {} in WebLogic server/cluster {}", name, this.getServerName() );
+    LOGGER.info( "Deploying JEE application {} in WebLogic server/cluster {}", name, this.getServerName() );
     try
     {
       DeployerRuntimeMBean deployerRuntime = DeployerRuntime.getDeployerRuntime( home );
@@ -254,15 +254,15 @@ public class WeblogicController
     }
     catch ( Exception e )
     {
-      LOGGER.error( "Can't deploy J2EE application {}", name, e );
-      throw new ControllerException( "Can't deploy J2EE application " + name, e );
+      LOGGER.error( "Can't deploy JEE application {}", name, e );
+      throw new ControllerException( "Can't deploy JEE application " + name, e );
     }
   }
 
-  public void undeployJ2EEApplication( String path, String name )
+  public void undeployJEEApplication(String path, String name)
     throws ControllerException
   {
-    LOGGER.info( "Undeploying J2EE application {} from WebLogic server/cluster {}", name, this.getServerName() );
+    LOGGER.info( "Undeploying JEE application {} from WebLogic server/cluster {}", name, this.getServerName() );
     try
     {
       DeployerRuntimeMBean deployerRuntime = DeployerRuntime.getDeployerRuntime( home );
@@ -285,15 +285,15 @@ public class WeblogicController
     }
     catch ( Exception e )
     {
-      LOGGER.error( "Can't undeploy J2EE application {}", name, e );
-      throw new ControllerException( "Can't undeploy J2EE application " + name, e );
+      LOGGER.error( "Can't undeploy JEE application {}", name, e );
+      throw new ControllerException( "Can't undeploy JEE application " + name, e );
     }
   }
 
-  public void redeployJ2EEApplication( String path, String name )
+  public void redeployJEEApplication(String path, String name)
     throws ControllerException
   {
-    LOGGER.info( "Redeploying J2EE application {} in WebLogic server/cluster {}", name, this.getServerName() );
+    LOGGER.info( "Redeploying JEE application {} in WebLogic server/cluster {}", name, this.getServerName() );
     try
     {
       DeployerRuntimeMBean deployerRuntime = DeployerRuntime.getDeployerRuntime( home );
@@ -316,8 +316,8 @@ public class WeblogicController
     }
     catch ( Exception e )
     {
-      LOGGER.error( "Can't redeploy J2EE application {}", name, e );
-      throw new ControllerException( "Can't redeploy J2EE application " + name, e );
+      LOGGER.error( "Can't redeploy JEE application {}", name, e );
+      throw new ControllerException( "Can't redeploy JEE application " + name, e );
     }
   }
 

Modified: incubator/kalumet/trunk/kalumet-modules/controller/websphere/src/main/java/org/apache/kalumet/controller/websphere/WebsphereController.java
URL: http://svn.apache.org/viewvc/incubator/kalumet/trunk/kalumet-modules/controller/websphere/src/main/java/org/apache/kalumet/controller/websphere/WebsphereController.java?rev=1379028&r1=1379027&r2=1379028&view=diff
==============================================================================
--- incubator/kalumet/trunk/kalumet-modules/controller/core/src/main/java/org/apache/kalumet/controller/core/J2EEApplicationServerControllerFactory.java (original)
+++ incubator/kalumet/trunk/kalumet-modules/controller/core/src/main/java/org/apache/kalumet/controller/core/JEEApplicationServerControllerFactory.java Thu Aug 30 17:31:27 2012
@@ -19,7 +19,7 @@
 package org.apache.kalumet.controller.core;
 
 import org.apache.kalumet.model.Environment;
-import org.apache.kalumet.model.J2EEApplicationServer;
+import org.apache.kalumet.model.JEEApplicationServer;
 import org.apache.kalumet.utils.VariableUtils;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
@@ -27,30 +27,30 @@ import org.slf4j.LoggerFactory;
 import java.lang.reflect.Constructor;
 
 /**
  * Factory to get a <code>J2EEApplicationServerController</code>.
  */
-public class J2EEApplicationServerControllerFactory
+public class JEEApplicationServerControllerFactory
 {
 
   private final static transient Logger LOGGER =
-    LoggerFactory.getLogger( J2EEApplicationServerControllerFactory.class );
+    LoggerFactory.getLogger( JEEApplicationServerControllerFactory.class );
 
-  public static J2EEApplicationServerController getController( Environment environment, J2EEApplicationServer server )
+  public static JEEApplicationServerController getController( Environment environment, JEEApplicationServer server )
     throws ControllerException
   {
     LOGGER.debug( "Connecting to {}", VariableUtils.replace( server.getJmxurl(), environment.getVariables() ) );
     String jmxUrl = VariableUtils.replace( server.getJmxurl(), environment.getVariables() );
     String adminUser = VariableUtils.replace( server.getAdminuser(), environment.getVariables() );
     String adminPassword = VariableUtils.replace( server.getAdminpassword(), environment.getVariables() );
-    J2EEApplicationServerController controller = null;
+    JEEApplicationServerController controller = null;
     try
     {
       Class controllerClass = Class.forName( server.getClassname() );
       Constructor controllerConstructor = controllerClass.getConstructor(
         new Class[]{ String.class, String.class, String.class, String.class, Boolean.class } );
-      controller = (J2EEApplicationServerController) controllerConstructor.newInstance(
+      controller = (JEEApplicationServerController) controllerConstructor.newInstance(
         new Object[]{ jmxUrl, adminUser, adminPassword, server.getName(),
-          new Boolean( environment.getJ2EEApplicationServers().isCluster() ) } );
+          new Boolean( environment.getJEEApplicationServers().isCluster() ) } );
     }
     catch ( Exception e )
     {
@@ -62,7 +62,7 @@ public class J2EEApplicationServerContro
       else
       {
         throw new ControllerException(
-          "Can't initialize controller. Check if the J2EE application server libraries are present in the agent classpath and check the agent log" );
+          "Can't initialize controller. Check if the JEE application server libraries are present in the agent classpath and check the agent log" );
       }
     }
     return controller;
@@ -27,30 +27,30 @@ import org.slf4j.LoggerFactory;
 
 /**
- * Factory to get a <code>J2EEApplicationServerController</code>.
+ * Factory to get a <code>JEEApplicationServerController</code>.
  */

Modified: incubator/kalumet/trunk/kalumet-modules/controller/jboss/src/main/java/org/apache/kalumet/controller/jboss/JBoss4Controller.java
URL: http://svn.apache.org/viewvc/incubator/kalumet/trunk/kalumet-modules/controller/jboss/src/main/java/org/apache/kalumet/controller/jboss/JBoss4Controller.java?rev=1379028&r1=1379027&r2=1379028&view=diff
==============================================================================
--- incubator/kalumet/trunk/kalumet-modules/controller/jboss/src/main/java/org/apache/kalumet/controller/jboss/JBoss6Controller.java (original)
+++ incubator/kalumet/trunk/kalumet-modules/controller/jboss/src/main/java/org/apache/kalumet/controller/jboss/JBoss6Controller.java Thu Aug 30 17:31:27 2012
@@ -21,7 +21,7 @@ package org.apache.kalumet.controller.jb
 import org.apache.commons.io.FileUtils;
 import org.apache.commons.lang.StringUtils;
 import org.apache.kalumet.FileManipulator;
-import org.apache.kalumet.controller.core.AbstractJ2EEApplicationServerController;
+import org.apache.kalumet.controller.core.AbstractJEEApplicationServerController;
 import org.apache.kalumet.controller.core.ControllerException;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
@@ -49,7 +49,7 @@ import java.util.List;
  * JBoss 6 controller.
  */
 public class JBoss6Controller
-  extends AbstractJ2EEApplicationServerController
+  extends AbstractJEEApplicationServerController
 {
 
   private final static transient Logger LOGGER = LoggerFactory.getLogger( JBoss6Controller.class );
@@ -241,7 +241,7 @@ public class JBoss6Controller
   /**
    * Format an application path in a JBoss compliant URL.
    *
    * @param path the J2EE application path.
    * @return the JBoss application URL.
    */
   private static String formatPathToUrl( String path )
@@ -259,10 +259,10 @@ public class JBoss6Controller
     }
   }
 
-  public boolean isJ2EEApplicationDeployed( String path, String name )
+  public boolean isJEEApplicationDeployed(String path, String name)
     throws ControllerException
   {
-    LOGGER.info( "Checking if J2EE application {} is deployed in the JBoss application server", name );
+    LOGGER.info( "Checking if JEE application {} is deployed in the JBoss application server", name );
     String applicationUrl = JBoss6Controller.formatPathToUrl( path );
     boolean deployed = false;
     JMXConnector connector = null;
@@ -276,8 +276,8 @@ public class JBoss6Controller
     }
     catch ( Exception e )
     {
-      LOGGER.error( "Can't check if J2EE application {} is deployed", name, e );
-      throw new ControllerException( "Can't check if J2EE application " + name + " is deployed", e );
+      LOGGER.error( "Can't check if JEE application {} is deployed", name, e );
+      throw new ControllerException( "Can't check if JEE application " + name + " is deployed", e );
     }
     finally
     {
@@ -296,11 +296,11 @@ public class JBoss6Controller
     return deployed;
   }
 
-  public void deployJ2EEApplication( String path, String name, String classloaderorder, String classloaderpolicy,
-                                     String vhost )
+  public void deployJEEApplication(String path, String name, String classloaderorder, String classloaderpolicy,
+                                   String vhost)
     throws ControllerException
   {
-    LOGGER.info( "Deploying J2EE application {} located {}", name, path );
+    LOGGER.info( "Deploying JEE application {} located {}", name, path );
     String applicationUrl = JBoss6Controller.formatPathToUrl( path );
     JMXConnector connector = null;
     try
@@ -312,8 +312,8 @@ public class JBoss6Controller
     }
     catch ( Exception e )
     {
-      LOGGER.error( "Can't deploy J2EE application {}", name, e );
-      throw new ControllerException( "Can't deploy J2EE application " + name, e );
+      LOGGER.error( "Can't deploy JEE application {}", name, e );
+      throw new ControllerException( "Can't deploy JEE application " + name, e );
     }
     finally
     {
@@ -331,10 +331,10 @@ public class JBoss6Controller
     }
   }
 
-  public void undeployJ2EEApplication( String path, String name )
+  public void undeployJEEApplication(String path, String name)
     throws ControllerException
   {
-    LOGGER.info( "Undeploying J2EE application {} located {}", name, path );
+    LOGGER.info( "Undeploying JEE application {} located {}", name, path );
     String applicationUrl = JBoss6Controller.formatPathToUrl( path );
     JMXConnector connector = null;
     try
@@ -347,8 +347,8 @@ public class JBoss6Controller
     }
     catch ( Exception e )
     {
-      LOGGER.error( "Can't undeploy J2EE application {}", name, e );
-      throw new ControllerException( "Can't undeploy J2EE application " + name, e );
+      LOGGER.error( "Can't undeploy JEE application {}", name, e );
+      throw new ControllerException( "Can't undeploy JEE application " + name, e );
     }
     finally
     {
@@ -366,10 +366,10 @@ public class JBoss6Controller
     }
   }
 
-  public void redeployJ2EEApplication( String path, String name )
+  public void redeployJEEApplication(String path, String name)
     throws ControllerException
   {
-    LOGGER.info( "Redeploying J2EE application {} located {}", name, path );
+    LOGGER.info( "Redeploying JEE application {} located {}", name, path );
     String applicationUrl = JBoss6Controller.formatPathToUrl( path );
     JMXConnector connector = null;
     try
@@ -382,8 +382,8 @@ public class JBoss6Controller
     }
     catch ( Exception e )
     {
-      LOGGER.error( "Can't redeploy J2EE application {}", name, e );
-      throw new ControllerException( "Can't redeploy J2EE application " + name, e );
+      LOGGER.error( "Can't redeploy JEE application {}", name, e );
+      throw new ControllerException( "Can't redeploy JEE application " + name, e );
     }
     finally
     {
@@ -241,7 +241,7 @@ public class JBoss6Controller
    * Format an application path in a JBoss compliant URL.
    *
-   * @param path the J2EE application path.
+   * @param path the JEE application path.
    * @return the JBoss application URL.
    */

Modified: incubator/kalumet/trunk/kalumet-modules/controller/weblogic/src/main/java/org/apache/kalumet/controller/weblogic/WeblogicController.java
URL: http://svn.apache.org/viewvc/incubator/kalumet/trunk/kalumet-modules/controller/weblogic/src/main/java/org/apache/kalumet/controller/weblogic/WeblogicController.java?rev=1379028&r1=1379027&r2=1379028&view=diff
==============================================================================
--- incubator/kalumet/trunk/kalumet-modules/controller/websphere/src/main/java/org/apache/kalumet/controller/websphere/WebsphereController.java (original)
+++ incubator/kalumet/trunk/kalumet-modules/controller/websphere/src/main/java/org/apache/kalumet/controller/websphere/WebsphereController.java Thu Aug 30 17:31:27 2012
@@ -29,7 +29,7 @@ import com.ibm.websphere.management.appl
 import com.ibm.websphere.management.configservice.ConfigServiceHelper;
 import com.ibm.websphere.management.configservice.ConfigServiceProxy;
 import com.ibm.websphere.management.configservice.SystemAttributes;
-import org.apache.kalumet.controller.core.AbstractJ2EEApplicationServerController;
+import org.apache.kalumet.controller.core.AbstractJEEApplicationServerController;
 import org.apache.kalumet.controller.core.ControllerException;
 import org.apache.oro.text.regex.MalformedPatternException;
 import org.apache.oro.text.regex.MatchResult;
@@ -58,7 +58,7 @@ import java.util.Set;
  * WebsphereController is the controller for IBM WebSphere Server 5.x and 6.x.
  */
 public class WebsphereController
-  extends AbstractJ2EEApplicationServerController
+  extends AbstractJEEApplicationServerController
 {
 
   private final static transient Logger LOGGER = LoggerFactory.getLogger( WebsphereController.class );
@@ -332,10 +332,10 @@ public class WebsphereController
     return stopped;
   }
 
-  public boolean isJ2EEApplicationDeployed( String path, String name )
+  public boolean isJEEApplicationDeployed(String path, String name)
     throws ControllerException
   {
-    LOGGER.info( "Checking if J2EE application {} is deployed", name );
+    LOGGER.info( "Checking if JEE application {} is deployed", name );
     boolean deployed = false;
     AdminClient admin = this.getConfigServiceProxy().getAdminClient();
     try
@@ -345,17 +345,17 @@ public class WebsphereController
     }
     catch ( Exception e )
     {
-      LOGGER.warn( "Can't check if J2EE application {} is deployed", name, e );
+      LOGGER.warn( "Can't check if JEE application {} is deployed", name, e );
       return false;
     }
     return deployed;
   }
 
-  public void deployJ2EEApplication( String path, String name, String classloaderorder, String classloaderpolicy,
-                                     String vhost )
+  public void deployJEEApplication(String path, String name, String classloaderorder, String classloaderpolicy,
+                                   String vhost)
     throws ControllerException
   {
-    LOGGER.info( "Deploying J2EE application {}", name );
+    LOGGER.info( "Deploying JEE application {}", name );
     AdminClient admin = this.getConfigServiceProxy().getAdminClient();
     ObjectName server = null;
     try
@@ -375,17 +375,17 @@ public class WebsphereController
       }
       if ( servers.isEmpty() )
       {
-        LOGGER.error( "IBM WebSphere server {} not found, can't deploy J2EE application {}", this.getServerName(),
+        LOGGER.error( "IBM WebSphere server {} not found, can't deploy JEE application {}", this.getServerName(),
                       name );
         throw new ControllerException(
-          "IBM WebSphere server " + this.getServerName() + " not found, can't deploy J2EE application " + name );
+          "IBM WebSphere server " + this.getServerName() + " not found, can't deploy JEE application " + name );
       }
       server = (ObjectName) servers.iterator().next();
       LOGGER.debug( "IBM WebSphere server {} MBean found", this.getServerName() );
       AppManagement appManagement = AppManagementProxy.getJMXProxyForClient( admin );
       // first, create the deployment controler and populate the archive file
       // with appropriate options
-      LOGGER.debug( "Defining J2EE application preferences" );
+      LOGGER.debug( "Defining JEE application preferences" );
       Hashtable preferences = new Hashtable();
       preferences.put( AppConstants.APPDEPL_LOCALE, Locale.getDefault() );
       preferences.put( AppConstants.APPDEPL_APPNAME, name );
@@ -416,11 +416,11 @@ public class WebsphereController
         vhost = "default_host";
       }
 
-      LOGGER.debug( "Creating J2EE application default bindings" );
+      LOGGER.debug( "Creating JEE application default bindings" );
       Properties defaultBinding = new Properties();
       defaultBinding.put( AppConstants.APPDEPL_DFLTBNDG_VHOST, vhost );
       preferences.put( AppConstants.APPDEPL_DFLTBNDG, defaultBinding );
-      LOGGER.debug( "Creating J2EE application options" );
+      LOGGER.debug( "Creating JEE application options" );
       Hashtable options = new Hashtable();
       options.put( AppConstants.APPDEPL_APPNAME, name );
       options.put( AppConstants.APPDEPL_LOCALE, Locale.getDefault() );
@@ -434,7 +434,7 @@ public class WebsphereController
       options.put( AppConstants.APPDEPL_CLASSLOADERPOLICY, AppConstants.APPDEPL_CLASSLOADERPOLICY_SINGLE );
       options.put( AppConstants.APPDEPL_DFLTBNDG, defaultBinding );
 
-      LOGGER.debug( "Defining J2EE application targets" );
+      LOGGER.debug( "Defining JEE application targets" );
       Hashtable module2server = new Hashtable();
       if ( this.isCluster() )
       {
@@ -448,7 +448,7 @@ public class WebsphereController
       }
       options.put( AppConstants.APPDEPL_MODULE_TO_SERVER, module2server );
       // install the JEE application
-      LOGGER.debug( "Installing J2EE application {}", name );
+      LOGGER.debug( "Installing JEE application {}", name );
       appManagement.installApplication( path, name, options, null );
       ConfigServiceProxy configService = this.getConfigServiceProxy();
       Thread.sleep( 5000 );
@@ -459,27 +459,27 @@ public class WebsphereController
       }
       // waiting for deployment
       int i = 0;
-      while ( !this.isJ2EEApplicationDeployed( path, name ) && i < 100 )
+      while ( !this.isJEEApplicationDeployed(path, name) && i < 100 )
       {
         Thread.sleep( 10000 );
         i++;
       }
       Thread.sleep( 60000 );
-      // start the J2EE application
-      LOGGER.debug( "Starting J2EE application {}", name );
+      // start the JEE application
+      LOGGER.debug( "Starting JEE application {}", name );
       appManagement.startApplication( name, preferences, null );
     }
     catch ( Exception e )
     {
-      LOGGER.error( "Can't deploy J2EE application {}", name, e );
-      throw new ControllerException( "Can't deploy J2EE application " + name, e );
+      LOGGER.error( "Can't deploy JEE application {}", name, e );
+      throw new ControllerException( "Can't deploy JEE application " + name, e );
     }
   }
 
-  public void undeployJ2EEApplication( String path, String name )
+  public void undeployJEEApplication(String path, String name)
     throws ControllerException
   {
-    LOGGER.info( "Undeploying J2EE application {}", name );
+    LOGGER.info( "Undeploying JEE application {}", name );
     AdminClient admin = this.getConfigServiceProxy().getAdminClient();
     try
     {
@@ -487,13 +487,13 @@ public class WebsphereController
       Hashtable preferences = new Hashtable();
       preferences.put( AppConstants.APPDEPL_LOCALE, Locale.getDefault() );
       preferences.put( AppConstants.APPDEPL_APPNAME, name );
-      LOGGER.debug( "Stopping J2EE application {}", name );
+      LOGGER.debug( "Stopping JEE application {}", name );
       appManagement.stopApplication( name, preferences, null );
-      LOGGER.debug( "Uninstalling J2EE application {}", name + " from IBM WebSphere server " + this.getServerName() );
+      LOGGER.debug( "Uninstalling JEE application {}", name + " from IBM WebSphere server " + this.getServerName() );
       appManagement.uninstallApplication( name, preferences, null );
       // waiting for undeployment
       int i = 0;
-      while ( this.isJ2EEApplicationDeployed( path, name ) && i < 100 )
+      while ( this.isJEEApplicationDeployed(path, name) && i < 100 )
       {
         Thread.sleep( 10000 );
         i++;
@@ -501,15 +501,15 @@ public class WebsphereController
     }
     catch ( Exception e )
     {
-      LOGGER.error( "Can't undeploy J2EE application {}", name, e );
-      throw new ControllerException( "Can't undeploy J2EE application " + name, e );
+      LOGGER.error( "Can't undeploy JEE application {}", name, e );
+      throw new ControllerException( "Can't undeploy JEE application " + name, e );
     }
   }
 
-  public void redeployJ2EEApplication( String path, String name )
+  public void redeployJEEApplication(String path, String name)
     throws ControllerException
   {
-    LOGGER.info( "Redeploying J2EE application {}", name );
+    LOGGER.info( "Redeploying JEE application {}", name );
     AdminClient admin = this.getConfigServiceProxy().getAdminClient();
     try
     {
@@ -521,8 +521,8 @@ public class WebsphereController
     }
     catch ( Exception e )
     {
-      LOGGER.error( "Can't redeploy J2EE application {}", name, e );
-      throw new ControllerException( "Can't redeploy J2EE application " + name, e );
+      LOGGER.error( "Can't redeploy JEE application {}", name, e );
+      throw new ControllerException( "Can't redeploy JEE application " + name, e );
     }
   }